@@ -19,6 +19,8 @@ from bokeh.plotting import figure
 from bokeh.layouts import row, column
 from bokeh.models import ColorBar, BasicTicker, LinearColorMapper, Legend  # type: ignore
 from bokeh.io import show, output_notebook
+from bokeh.embed import file_html  # Those two imports are necessary for the notebooks_tests
+from bokeh.resources import CDN
 from matplotlib.colors import LinearSegmentedColormap
 from matplotlib import cm
 from matplotlib.image import imsave
@@ -27,7 +29,6 @@ import plotly.express as px  # type: ignore
 
 
 def pandora_cmap():
-
     colors = ["crimson", "lightpink", "white", "yellowgreen"]
     nodes = [0.0, 0.4, 0.5, 1.0]
     cmap_shift = LinearSegmentedColormap.from_list("mycmap", list(zip(nodes, colors)))
@@ -36,7 +37,6 @@ def pandora_cmap():
 
 
 def cmap_to_palette(cmap):
-
     cmap_rgb = (255 * cmap(range(256))).astype("int")
     palette = [RGB(*tuple(rgb)).to_hex() for rgb in cmap_rgb]
 
