@@ -96,12 +96,12 @@ class CrossBasedCostAggregation(aggregation.AbstractAggregation):
 
         :param img_left: left Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk (optional): 2D (row, col) xarray.DataArray
         :type img_left: xarray.Dataset
         :param img_right: right Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk (optional): 2D (row, col) xarray.DataArray
         :type img_right: xarray.Dataset
         :param cv: cost volume dataset with the data variables:
@@ -196,12 +196,12 @@ class CrossBasedCostAggregation(aggregation.AbstractAggregation):
 
         :param img_left: left Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk (optional): 2D (row, col) xarray.DataArray
         :type img_left: xarray.Dataset
         :param img_right: right Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk (optional): 2D (row, col) xarray.DataArray
         :type img_right: xarray.Dataset
         :param cv: cost volume dataset with the data variables:
@@ -473,7 +473,6 @@ def cross_support(image: np.ndarray, len_arms: int, intensity: float) -> np.ndar
 
     for col in range(n_col_):
         for row in range(n_row_):
-
             # If the pixel is valid (np.isfinite = True) compute the cross support
             # Else (np.isfinite = False) the pixel is not valid (no data or invalid) and the cross support value is 0
             # for the 4 arms (default value of the variable cross).
