@@ -88,15 +88,8 @@ def check_images(img_left: str, img_right: str, msk_left: str, msk_right: str) -
     :type msk_right: string
     :return: None
     """
-    # verify that the images have 1 channel
     left_ = rasterio_open(img_left)
-    if left_.count != 1:
-        logging.error("The input images must be 1-channel grayscale images")
-        sys.exit(1)
     right_ = rasterio_open(img_right)
-    if right_.count != 1:
-        logging.error("The input images must be 1-channel grayscale images")
-        sys.exit(1)
 
     # verify that the images have the same size
     if (left_.width != right_.width) or (left_.height != right_.height):
@@ -119,6 +112,61 @@ def check_images(img_left: str, img_right: str, msk_left: str, msk_right: str) -
             sys.exit(1)
 
 
+def check_band_names(img: str) -> None:
+    """
+    Check that band names have the correct format
+
+    :param img: path to the image
+    :type img: string
+    :return: None
+    """
+
+    # open image
+    img_ds = rasterio_open(img)
+    img_array = img_ds.read()
+
+    # check that the image have the band names
+    if img_array.shape[0] != 1:
+        if not img_ds.descriptions:
+            logging.error("Image is missing band names metadata")
+            sys.exit(1)
+        if not all(isinstance(band, str) for band in list(img_ds.descriptions)):
+            logging.error("Band value must be str")
+            sys.exit(1)
+
+
+def check_band_pipeline(img: str, step: str, bands: Union[None, str, List[str], Dict]) -> None:
+    """
+    Check coherence band parameter between pipeline step and image dataset
+
+    :param img: path to the image
+    :type img: str
+    :param step: pipeline step
+    :type step: str
+    :param bands: band names
+    :type bands: None, str, List[str] or Dict
+    :return: None
+    """
+    # open images
+    img_ds = rasterio_open(img)
+    # If no bands are given, then the input image shall be monoband
+    if not bands:
+        if img_ds.count != 1:
+            logging.error("Missing band instantiate on %s step : input image is multiband", step)
+            sys.exit(1)
+    # check that the image have the band names
+    elif isinstance(bands, dict):
+        for _, band in bands.items():
+            if not band in list(img_ds.descriptions):
+                logging.error("Wrong band instantiate on %s step: %s not in input image", step, band)
+                sys.exit(1)
+    else:
+        for band in bands:
+            if not band in list(img_ds.descriptions):
+                logging.error("Wrong band instantiate %s step: %s not in input image", step, band)
+                sys.exit(1)
+
+
 def check_disparities(
     disp_min: Union[int, str, None],
     disp_max: Union[int, str, None],
@@ -338,6 +386,9 @@ def check_input_section(user_cfg: Dict[str, dict]) -> Dict[str, dict]:
         cfg["input"]["img_left"],
     )
 
+    check_band_names(cfg["input"]["img_left"])
+    check_band_names(cfg["input"]["img_right"])
+
     check_images(
         cfg["input"]["img_left"],
         cfg["input"]["img_right"],
@@ -368,9 +419,45 @@ def check_conf(user_cfg: Dict[str, dict], pandora_machine: PandoraMachine) -> di
     user_cfg_pipeline = get_config_pipeline(user_cfg)
     cfg_pipeline = check_pipeline_section(user_cfg_pipeline, pandora_machine)
 
+    # Check band for the matching_cost step
+    check_band_pipeline(
+        cfg_input["input"]["img_left"],
+        cfg_pipeline["pipeline"]["matching_cost"]["matching_cost_method"],
+        cfg_pipeline["pipeline"]["matching_cost"]["band"],
+    )
+    check_band_pipeline(
+        cfg_input["input"]["img_right"],
+        cfg_pipeline["pipeline"]["matching_cost"]["matching_cost_method"],
+        cfg_pipeline["pipeline"]["matching_cost"]["band"],
+    )
+
+    # If validation is present, right disparity map computation must be activated
+    if cfg_pipeline["pipeline"]["right_disp_map"]["method"] != "accurate":
+        right_disp_computation = False
+        if "validation" in cfg_pipeline["pipeline"]:
+            logging.error('For cross-checking, right_disp_map must be set to "accurate"')
+            sys.exit(1)
+    else:
+        right_disp_computation = True
+
+    # If semantic_segmentation is present, check that the RGB band are present in left image
+    if "semantic_segmentation" in cfg_pipeline["pipeline"]:
+        check_band_pipeline(
+            cfg_input["input"]["img_left"],
+            cfg_pipeline["pipeline"]["semantic_segmentation"]["segmentation_method"],
+            cfg_pipeline["pipeline"]["semantic_segmentation"]["RGB_bands"],
+        )
+        # If semantic_segmentation and right_disp_computation is present,
+        # check that the RGB band are present in the right image
+        if right_disp_computation:
+            check_band_pipeline(
+                cfg_input["input"]["img_right"],
+                cfg_pipeline["pipeline"]["semantic_segmentation"]["segmentation_method"],
+                cfg_pipeline["pipeline"]["semantic_segmentation"]["RGB_bands"],
+            )
+
     # If left disparities are grids of disparity and the right disparities are none, the cross-checking
     # method cannot be used
-
     if (
         (isinstance(cfg_input["input"]["disp_min"], str))
         and (cfg_input["input"]["disp_min_right"] is None)
@@ -391,6 +478,27 @@ def check_conf(user_cfg: Dict[str, dict], pandora_machine: PandoraMachine) -> di
         logging.error("Multiscale processing does not accept input disparity grids.")
         sys.exit(1)
 
+    # If segmentation or classif geometric_prior is needed for the optimization step,
+    # check that it is present on the input config
+    if "optimization" in cfg_pipeline["pipeline"]:
+        if "geometric_prior" in cfg_pipeline["pipeline"]["optimization"]:
+            source = cfg_pipeline["pipeline"]["optimization"]["geometric_prior"]["source"]
+            if source in ["classif", "segm"]:
+                if not cfg_input["input"]["left_" + source]:
+                    logging.error(
+                        "For performing the 3SGM optimization step in the pipeline, left %s must be present.", source
+                    )
+                    sys.exit(1)
+                # If right_disp_computation is to be done and 3SGM optimization is present on the pipeline,
+                # then both left and right segmentations/classifications must be present
+                if right_disp_computation and not cfg_input["input"]["right_" + source]:
+                    logging.error(
+                        "For performing right disparity computation with 3SGM optimization in the pipeline,"
+                        " both left and right %s must be present.",
+                        source,
+                    )
+                    sys.exit(1)
+
     # concatenate updated config
     cfg = concat_conf([cfg_input, cfg_pipeline])
 
