@@ -41,7 +41,7 @@ class StdIntensity(cost_volume_confidence.AbstractCostVolumeConfidence):
     """
 
     # Method name
-    _method = "confidence_from_intensity_std"
+    _method = "intensity_std"
     # Indicator
     _indicator = ""
 
@@ -104,7 +104,9 @@ class StdIntensity(cost_volume_confidence.AbstractCostVolumeConfidence):
 
                 - confidence_measure 3D xarray.DataArray (row, col, indicator)
         """
-        nb_row, nb_col = img_left["im"].shape
+
+        nb_row, nb_col = img_left.dims["row"], img_left.dims["col"]
+        band = cv.attrs["band_correl"]
 
         window_size = cv.attrs["window_size"]
         confidence_measure = np.full((nb_row, nb_col), np.nan, dtype=np.float32)
@@ -112,10 +114,10 @@ class StdIntensity(cost_volume_confidence.AbstractCostVolumeConfidence):
         offset_row_col = int((window_size - 1) / 2)
         if offset_row_col != 0:
             confidence_measure[offset_row_col:-offset_row_col, offset_row_col:-offset_row_col] = compute_std_raster(
-                img_left, window_size
+                img_left, window_size, band
             )
         else:
-            confidence_measure = compute_std_raster(img_left, window_size)
+            confidence_measure = compute_std_raster(img_left, window_size, band)
 
         disp, cv = self.allocate_confidence_map(self._indicator, confidence_measure, disp, cv)
         return disp, cv
