@@ -23,7 +23,6 @@
 This module contains functions associated to the disparity map computation step.
 """
 
-import logging
 from abc import ABCMeta, abstractmethod
 from typing import Dict, Union, Tuple
 
@@ -57,22 +56,17 @@ class AbstractDisparity:
             if isinstance(cfg["disparity_method"], str):
                 try:
                     return super(AbstractDisparity, cls).__new__(cls.disparity_methods_avail[cfg["disparity_method"]])
-                except KeyError:
-                    logging.error("No disparity method named % supported", cfg["disparity_method"])
-                    raise KeyError
+                except:
+                    raise KeyError("No disparity method named {} supported".format(cfg["disparity_method"]))
             else:
-                if isinstance(cfg["disparity_method"], unicode):  # type: ignore # pylint: disable=undefined-variable
+                if isinstance(cfg["disparity_method"], unicode):  # type:ignore # pylint:disable=undefined-variable
                     # creating a plugin from registered short name given as unicode (py2 & 3 compatibility)
                     try:
                         return super(AbstractDisparity, cls).__new__(
                             cls.disparity_methods_avail[cfg["disparity_method"].encode("utf-8")]
                         )
-                    except KeyError:
-                        logging.error(
-                            "No disparity method named % supported",
-                            cfg["disparity_method"],
-                        )
-                        raise KeyError
+                    except:
+                        raise KeyError("No disparity method named {} supported".format(cfg["disparity_method"]))
         else:
             return super(AbstractDisparity, cls).__new__(cls)
         return None
@@ -117,12 +111,12 @@ class AbstractDisparity:
         :type cv: xarray.Dataset,
         :param img_left: left Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_left: xarray.Dataset
         :param img_right: right Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_right: xarray.Dataset
         :return: Dataset with the disparity map and the confidence measure with the data variables :
@@ -171,7 +165,7 @@ class AbstractDisparity:
         :type cv: xarray.Dataset
         :param img_right: right Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_right: xarray.Dataset
         :param invalid_value: disparity to assign to invalid pixels
@@ -240,11 +234,11 @@ class AbstractDisparity:
 
             # The disparity interval is missing in the left image
             if x_d[valid].size == 0:
-                disp_map["disparity_map"].loc[dict(col=col)] = invalid_value
+                disp_map["disparity_map"].loc[{"col": col}] = invalid_value
 
                 # Invalid pixel : the disparity interval is missing in the right image
                 disp_map["validity_mask"].loc[
-                    dict(col=col)
+                    {"col": col}
                 ] += cst.PANDORA_MSK_PIXEL_RIGHT_NODATA_OR_DISPARITY_RANGE_MISSING
             else:
                 # Diagonal search for the minimum or maximum
@@ -271,10 +265,10 @@ class AbstractDisparity:
                 if x_d[valid].size != disp_range.size:
                     #  Information: the disparity interval is incomplete (border reached in the right image)
                     disp_map["validity_mask"].loc[
-                        dict(col=col)
+                        {"col": col}
                     ] += cst.PANDORA_MSK_PIXEL_RIGHT_INCOMPLETE_DISPARITY_RANGE
 
-                disp_map["disparity_map"].loc[dict(col=col)] = -1 * np.flip(disp_range[valid])[min_.data]  # type:ignore
+                disp_map["disparity_map"].loc[{"col": col}] = -1 * np.flip(disp_range[valid])[min_.data]  # type:ignore
 
         cv["cost_volume"].data[indices_nan] = np.nan
         invalid_mc = np.min(indices_nan, axis=2)
@@ -304,12 +298,12 @@ class AbstractDisparity:
                 - confidence_measure 3D xarray.DataArray(row, col, indicator)
         :param img_left: left Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_left: xarray.Dataset
         :param img_right: right Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_right: xarray.Dataset
         :param cv: cost volume dataset with the data variables:
@@ -448,7 +442,7 @@ class AbstractDisparity:
         :type disp: xarray.Dataset
         :param img_left: left Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_left: xarray.Dataset
         :return: None
@@ -484,7 +478,7 @@ class AbstractDisparity:
         :type disp: xarray.Dataset
         :param img_right: left Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_right: xarray.Dataset
         :param bit_1: where the disparity interval is missing in the right image ( disparity range outside the image )
@@ -605,12 +599,12 @@ class WinnerTakesAll(AbstractDisparity):
         :type cv: xarray.Dataset
         :param img_left: left Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_left: xarray.Dataset
         :param img_right: right Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_right: xarray.Dataset
         :return: Dataset with the disparity map and the confidence measure  with the data variables :
