@@ -27,7 +27,7 @@ from typing import Dict, Union, Tuple, List
 
 import numpy as np
 import xarray as xr
-from json_checker import Checker, And
+from json_checker import Checker, And, Or
 
 from pandora.img_tools import shift_right_img, census_transform
 from pandora.matching_cost import matching_cost
@@ -39,19 +39,14 @@ class Census(matching_cost.AbstractMatchingCost):
     Census class allows to compute the cost volume
     """
 
-    # Default configuration, do not change these values
-    _WINDOW_SIZE = 5
-    _SUBPIX = 1
-
     def __init__(self, **cfg: Dict[str, Union[str, int]]) -> None:
         """
         :param cfg: optional configuration,  {'window_size': value, 'subpix': value}
         :type cfg: dict
         :return: None
         """
-        self.cfg = self.check_conf(**cfg)
-        self._window_size = self.cfg["window_size"]
-        self._subpix = self.cfg["subpix"]
+
+        super().instantiate_class(**cfg)  # type: ignore
 
     def check_conf(self, **cfg: Dict[str, Union[str, int]]) -> Dict[str, Union[str, int]]:
         """
@@ -62,21 +57,18 @@ class Census(matching_cost.AbstractMatchingCost):
         :return cfg: matching cost configuration updated
         :rtype: dict
         """
-        # Give the default value if the required element is not in the conf
-        if "window_size" not in cfg:
-            cfg["window_size"] = self._WINDOW_SIZE  # type: ignore
-        if "subpix" not in cfg:
-            cfg["subpix"] = self._SUBPIX  # type: ignore
+        cfg = super().check_conf(**cfg)
 
         schema = {
             "matching_cost_method": And(str, lambda input: "census"),
             "window_size": And(int, lambda input: input in (3, 5)),
             "subpix": And(int, lambda input: input > 0 and ((input % 2) == 0) or input == 1),
+            "band": Or(str, lambda input: input is None),
         }
 
         checker = Checker(schema)
         checker.validate(cfg)
-        return cfg  # type: ignore
+        return cfg
 
     def desc(self) -> None:
         """
@@ -93,12 +85,12 @@ class Census(matching_cost.AbstractMatchingCost):
 
         :param img_left: left Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_left: xarray.Dataset
         :param img_right: right Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_right: xarray.Dataset
         :param disp_min: minimum disparity
@@ -110,12 +102,15 @@ class Census(matching_cost.AbstractMatchingCost):
                 - cost_volume 3D xarray.DataArray (row, col, disp)
         :rtype: xarray.Dataset
         """
+        # check band parameter
+        self.check_band_input_mc(img_left, img_right)
+
         # Contains the shifted right images
-        img_right_shift = shift_right_img(img_right, self._subpix)
+        img_right_shift = shift_right_img(img_right, self._subpix, self._band)  # type: ignore
 
         # Maximal cost of the cost volume with census measure
-        cmax = int(self._window_size**2)
-        offset_row_col = int((self._window_size - 1) / 2)
+        cmax = int(self._window_size**2)  # type: ignore
+        offset_row_col = int((self._window_size - 1) / 2)  # type: ignore
         metadata = {
             "measure": "census",
             "subpixel": self._subpix,
@@ -123,12 +118,13 @@ class Census(matching_cost.AbstractMatchingCost):
             "window_size": self._window_size,
             "type_measure": "min",
             "cmax": cmax,
+            "band_correl": self._band,
         }
 
         # Apply census transformation
-        left = census_transform(img_left, self._window_size)
+        left = census_transform(img_left, self._window_size, self._band)  # type: ignore
         for i, img in enumerate(img_right_shift):
-            img_right_shift[i] = census_transform(img, self._window_size)
+            img_right_shift[i] = census_transform(img, self._window_size, self._band)  # type: ignore
 
         # Disparity range # pylint: disable=undefined-variable
         if self._subpix == 1:
@@ -137,18 +133,7 @@ class Census(matching_cost.AbstractMatchingCost):
             disparity_range = np.arange(disp_min, disp_max, step=1 / float(self._subpix))  # type: ignore
             disparity_range = np.append(disparity_range, [disp_max])
 
-        # Allocate the numpy cost volume cv = (disp, col, row), for efficient memory management
-        cv = np.zeros(
-            (len(disparity_range), img_left["im"].shape[1], img_left["im"].shape[0]),
-            dtype=np.float32,
-        )
-        cv += np.nan
-
-        # If offset, do not consider border position for cost computation
-        if offset_row_col != 0:
-            cv_crop = cv[:, offset_row_col:-offset_row_col, offset_row_col:-offset_row_col]
-        else:
-            cv_crop = cv
+        cv, cv_crop = self.allocate_numpy_cost_volume(img_left, disparity_range, offset_row_col)
 
         # Giving the 2 images, the matching cost will be calculated as :
         #                 1, 1, 1                2, 5, 6
@@ -192,10 +177,10 @@ class Census(matching_cost.AbstractMatchingCost):
         # Create the xarray.DataSet that will contain the cv of dimensions (row, col, disp)
         cv = self.allocate_costvolume(
             img_left,
-            self._subpix,
+            self._subpix,  # type: ignore
             disp_min,
             disp_max,
-            self._window_size,
+            self._window_size,  # type: ignore
             metadata,
             np.swapaxes(cv, 0, 2),
         )
@@ -221,12 +206,12 @@ class Census(matching_cost.AbstractMatchingCost):
         :type point_q: tuple
         :param img_left: left Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk (optional): 2D (row, col) xarray.DataArray
         :type img_left: xarray.Dataset
         :param img_right: right Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk (optional): 2D (row, col) xarray.DataArray
         :type img_right: xarray.Dataset
         :return: the xor pixel-wise between elements in the interval
