@@ -23,7 +23,6 @@
 This module contains classes and functions associated to the validation step.
 """
 
-import logging
 from abc import ABCMeta, abstractmethod
 from typing import Dict, Union
 
@@ -61,12 +60,8 @@ class AbstractValidation:
                     return super(AbstractValidation, cls).__new__(
                         cls.validation_methods_avail[cfg["validation_method"]]
                     )
-                except KeyError:
-                    logging.error(
-                        "No validation method named % supported",
-                        cfg["validation_method"],
-                    )
-                    raise KeyError
+                except:
+                    raise KeyError("No validation method named {} supported".format(cfg["validation_method"]))
             else:
                 if isinstance(cfg["validation_method"], unicode):  # type: ignore # pylint: disable=undefined-variable
                     # creating a plugin from registered short name given as unicode (py2 & 3 compatibility)
@@ -74,12 +69,8 @@ class AbstractValidation:
                         return super(AbstractValidation, cls).__new__(
                             cls.validation_methods_avail[cfg["validation_method"].encode("utf-8")]
                         )
-                    except KeyError:
-                        logging.error(
-                            "No validation method named % supported",
-                            cfg["validation_method"],
-                        )
-                        raise KeyError
+                    except:
+                        raise KeyError("No validation method named {} supported".format(cfg["validation_method"]))
         else:
             return super(AbstractValidation, cls).__new__(cls)
         return None
@@ -145,12 +136,12 @@ class AbstractValidation:
         :type dataset_right: xarray.Dataset
         :param img_left: left Datset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_left: xarray.Dataset
         :param img_right: right Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_right: xarray.Dataset
         :param cv: cost_volume Dataset with the variables:
@@ -248,12 +239,12 @@ class CrossChecking(AbstractValidation):
         :type dataset_right: xarray.Dataset
         :param img_left: left Datset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_left: xarray.Dataset
         :param img_right: right Dataset image containing :
 
-                - im : 2D (row, col) xarray.DataArray
+                - im : 2D (row, col) or 3D (band, row, col) xarray.DataArray
                 - msk : 2D (row, col) xarray.DataArray
         :type img_right: xarray.Dataset
         :param cv: cost_volume Dataset with the variables:
@@ -347,7 +338,7 @@ class CrossChecking(AbstractValidation):
         dataset_left.attrs["validation"] = "cross_checking"
 
         dataset_left, _ = AbstractCostVolumeConfidence.allocate_confidence_map(
-            "validation_pandora_distance_of_disp", conf_measure, dataset_left, cv
+            "left_right_consistency", conf_measure, dataset_left, cv
         )
 
         return dataset_left
