@@ -26,6 +26,7 @@ This module contains functions to test the configuration
 import unittest
 import copy
 import json_checker
+import pytest
 from transitions import MachineError
 
 import numpy as np
@@ -257,6 +258,104 @@ class TestConfig(unittest.TestCase):
         # Json checker must raise an error
         self.assertRaises(json_checker.core.exceptions.DictCheckerError, JSON_checker.check_input_section, cfg)
 
+    def test_multiband_pipeline(self):
+        """
+        Test the method check_conf for multiband images
+        """
+        pandora_machine = PandoraMachine()
+        cfg = {
+            "input": copy.deepcopy(common.input_multiband_cfg),
+            "pipeline": {
+                "matching_cost": {"matching_cost_method": "zncc", "window_size": 5, "subpix": 2, "band": "r"},
+                "disparity": {"disparity_method": "wta"},
+            },
+        }
+
+        cfg_return = JSON_checker.check_conf(cfg, pandora_machine)
+
+        cfg_gt = {
+            "input": {
+                "nodata_left": -9999,
+                "nodata_right": -9999,
+                "left_mask": None,
+                "right_mask": None,
+                "left_classif": None,
+                "left_segm": None,
+                "right_classif": None,
+                "right_segm": None,
+                "disp_min_right": None,
+                "disp_max_right": None,
+                "img_left": "tests/pandora/left_rgb.tif",
+                "img_right": "tests/pandora/right_rgb.tif",
+                "disp_min": -60,
+                "disp_max": 0,
+            },
+            "pipeline": copy.deepcopy(common.basic_pipeline_cfg),
+        }
+        # correct band for correlation
+        cfg_gt["pipeline"]["matching_cost"]["band"] = "r"
+
+        del cfg_gt["pipeline"]["refinement"]
+        del cfg_gt["pipeline"]["filter"]
+
+        assert cfg_return == cfg_gt
+
+    def test_failed_multiband_pipeline(self):
+        """
+        Test the method check_conf for multiband images with errors
+        """
+
+        pandora_machine = PandoraMachine()
+
+        # config with wrong band parameters
+        cfg = {
+            "input": copy.deepcopy(common.input_multiband_cfg),
+            "pipeline": {
+                "matching_cost": {"matching_cost_method": "zncc", "window_size": 5, "subpix": 2, "band": "n"},
+                "disparity": {"disparity_method": "wta"},
+            },
+        }
+        # Check that the check_conf function raises an error
+        with pytest.raises(SystemExit):
+            JSON_checker.check_conf(cfg, pandora_machine)
+        # Check that the check_band_pipeline raises an error (this shall be the source of check_conf's error)
+        with pytest.raises(SystemExit):
+            JSON_checker.check_band_pipeline(
+                cfg["input"]["img_left"],
+                cfg["pipeline"]["matching_cost"]["matching_cost_method"],
+                cfg["pipeline"]["matching_cost"]["band"],
+            )
+        with pytest.raises(SystemExit):
+            JSON_checker.check_band_pipeline(
+                cfg["input"]["img_right"],
+                cfg["pipeline"]["matching_cost"]["matching_cost_method"],
+                cfg["pipeline"]["matching_cost"]["band"],
+            )
+
+        # config with missing band parameters
+        cfg = {
+            "input": copy.deepcopy(common.input_multiband_cfg),
+            "pipeline": {
+                "matching_cost": {"matching_cost_method": "zncc", "window_size": 5, "subpix": 2},
+                "disparity": {"disparity_method": "wta"},
+            },
+        }
+
+        # Check that the check_conf function raises an error
+        with pytest.raises(SystemExit):
+            JSON_checker.check_conf(cfg, pandora_machine)
+        # Check that the check_band_pipeline raises an error (this shall be the source of check_conf's error)
+        with pytest.raises(SystemExit):
+            # We add the band argument ad None because normally it is completed in the check_conf function,
+            # which then calls check_band_pipeline
+            JSON_checker.check_band_pipeline(
+                cfg["input"]["img_left"], cfg["pipeline"]["matching_cost"]["matching_cost_method"], bands=None
+            )
+        with pytest.raises(SystemExit):
+            JSON_checker.check_band_pipeline(
+                cfg["input"]["img_right"], cfg["pipeline"]["matching_cost"]["matching_cost_method"], bands=None
+            )
+
     @staticmethod
     def test_update_conf():
         """
@@ -399,6 +498,7 @@ class TestConfig(unittest.TestCase):
             },
             "pipeline": copy.deepcopy(common.basic_pipeline_cfg),
         }
+
         del cfg_gt["pipeline"]["refinement"]
         del cfg_gt["pipeline"]["filter"]
         assert cfg_return == cfg_gt
@@ -615,6 +715,25 @@ class TestConfig(unittest.TestCase):
         )
         np.testing.assert_allclose((min_mem_consump, max_mem_consump), consumption_vt, rtol=1e-02)
 
+    def test_right_disp_map_none_with_validation(self):
+        """
+        Test that user can't implement validation with right_disp_map set to none
+        """
+
+        cfg_pipeline = {
+            "pipeline": {
+                "right_disp_map": {"method": "none"},
+                "matching_cost": {"matching_cost_method": "census", "window_size": 5, "subpix": 2},
+                "disparity": {"disparity_method": "wta", "invalid_disparity": -9999},
+                "filter": {"filter_method": "median"},
+                "validation": {"validation_method": "cross_checking"},
+            }
+        }
+
+        pandora_machine = PandoraMachine()
+
+        self.assertRaises(MachineError, JSON_checker.check_pipeline_section, cfg_pipeline, pandora_machine)
+
 
 if __name__ == "__main__":
     common.setup_logging()
