@@ -22,9 +22,10 @@
 # limitations under the License.
 #
 """
-This module contains functions to test the cost volume measure step.
+This module contains functions to test the SAD matching cost step.
 """
 import unittest
+import pytest
 
 import numpy as np
 import xarray as xr
@@ -34,10 +35,10 @@ from pandora import matching_cost
 from tests import common
 
 
-class TestMatchingCost(unittest.TestCase):
+class TestMatchingCostSAD(unittest.TestCase):
     """
-    TestMatchingCost class allows to test all the methods in the class MatchingCost,
-    and the plugins pixel_wise, zncc
+    TestMatchingCost class allows to test all the methods in the
+    matching_cost SAD class
     """
 
     def setUp(self):
@@ -47,6 +48,7 @@ class TestMatchingCost(unittest.TestCase):
         """
 
         self.left, self.right = common.matching_cost_tests_setup()
+        self.left_multiband, self.right_multiband = common.matching_cost_tests_multiband_setup()
 
     def test_sad_cost(self):
         """
@@ -100,6 +102,63 @@ class TestMatchingCost(unittest.TestCase):
         # Check if the calculated ad cost is equal to the ground truth (same shape and all elements equals)
         np.testing.assert_array_equal(sad["cost_volume"].sel(disp=0), sad_ground_truth)
 
+    def test_sad_cost_multiband(self):
+        """
+        Test the absolute difference method
+
+        """
+        # Absolute difference pixel-wise ground truth for the images self.left, self.right
+        ad_ground_truth = np.array(
+            (
+                [0, 0, 0, 1, 1, 1],
+                [0, 0, 0, abs(1 - 4), 0, abs(1 - 4)],
+                [0, 0, 0, 0, abs(3 - 4), 0],
+                [0, 0, 0, 0, 0, 0],
+                [0, 0, 0, 0, 0, 0],
+            )
+        )
+
+        # Computes the ad cost for the whole images
+        matching_cost_matcher = matching_cost.AbstractMatchingCost(
+            **{"matching_cost_method": "sad", "window_size": 1, "subpix": 1, "band": "r"}
+        )
+        sad = matching_cost_matcher.compute_cost_volume(
+            img_left=self.left_multiband, img_right=self.right_multiband, disp_min=-1, disp_max=1
+        )
+
+        # Check if the calculated ad cost is equal to the ground truth (same shape and all elements equals)
+        np.testing.assert_array_equal(sad["cost_volume"].sel(disp=0), ad_ground_truth)
+
+        # Sum of absolute difference pixel-wise ground truth for the images self.left, self.right with window size 5
+        sad_ground_truth = np.array(
+            (
+                [
+                    [np.nan, np.nan, np.nan, np.nan, np.nan, np.nan],
+                    [np.nan, np.nan, np.nan, np.nan, np.nan, np.nan],
+                    [np.nan, np.nan, 6.0, 10.0, np.nan, np.nan],
+                    [np.nan, np.nan, np.nan, np.nan, np.nan, np.nan],
+                    [np.nan, np.nan, np.nan, np.nan, np.nan, np.nan],
+                ]
+            )
+        )
+        # Computes the ad cost for the whole images
+        matching_cost_matcher = matching_cost.AbstractMatchingCost(
+            **{"matching_cost_method": "sad", "window_size": 5, "subpix": 1, "band": "r"}
+        )
+        sad = matching_cost_matcher.compute_cost_volume(
+            img_left=self.left_multiband, img_right=self.right_multiband, disp_min=-1, disp_max=1
+        )
+        matching_cost_matcher.cv_masked(self.left_multiband, self.right_multiband, sad, -1, 1)
+
+        # Compute gt cmax:
+        window_size = 5
+        sad_cmax_ground_truth = np.max(ad_ground_truth) * window_size**2
+        # Check if the calculated ad cost is equal to the ground truth (same shape and all elements equals)
+        np.testing.assert_array_equal(sad["cost_volume"].sel(disp=0), sad_ground_truth)
+
+        # Check if the calculated max cost is equal to the ground truth
+        np.testing.assert_array_equal(sad.attrs["cmax"], sad_cmax_ground_truth)
+
     @staticmethod
     def test_cost_volume():
         """
@@ -113,12 +172,14 @@ class TestMatchingCost(unittest.TestCase):
         )
         left.attrs["crs"] = None
         left.attrs["transform"] = Affine(1.0, 0.0, 0.0, 0.0, 1.0, 0.0)
+
         data = np.array(([6, 7, 8, 10], [2, 4, 1, 6], [9, 10, 1, 2]), dtype=np.float64)
         right = xr.Dataset(
             {"im": (["row", "col"], data)}, coords={"row": np.arange(data.shape[0]), "col": np.arange(data.shape[1])}
         )
         right.attrs["crs"] = None
         right.attrs["transform"] = Affine(1.0, 0.0, 0.0, 0.0, 1.0, 0.0)
+
         # Cost Volume ground truth for the stereo image simple_stereo_imgs,
         # with disp_min = -2, disp_max = 1, sad measure and subpixel_offset = 0
         ground_truth = np.array(
@@ -841,6 +902,88 @@ class TestMatchingCost(unittest.TestCase):
         # Check if the calculated cost volume is equal to the ground truth (same shape and all elements equals)
         np.testing.assert_array_equal(cv["cost_volume"], cv_ground_truth)
 
+    @staticmethod
+    def test_check_band_sad():
+        """
+        Test the multiband choice for census measure with wrong matching_cost initialization
+        """
+
+        # Initialize multiband data
+        data = np.zeros((2, 4, 4))
+        data[0, :, :] = np.array(
+            (
+                [1, 1, 1, 3],
+                [1, 3, 2, 5],
+                [2, 1, 0, 1],
+                [1, 5, 4, 3],
+            ),
+            dtype=np.float64,
+        )
+
+        data[1, :, :] = np.array(
+            (
+                [2, 3, 4, 6],
+                [8, 7, 0, 4],
+                [4, 9, 1, 5],
+                [6, 5, 2, 1],
+            ),
+            dtype=np.float64,
+        )
+
+        left = xr.Dataset(
+            {"im": (["band", "row", "col"], data)},
+            coords={"band": np.arange(data.shape[0]), "row": np.arange(data.shape[1]), "col": np.arange(data.shape[2])},
+        )
+
+        left.attrs = common.img_attrs
+
+        # Initialize multiband data
+        data = np.zeros((2, 4, 4))
+        data[0, :, :] = np.array(
+            (
+                [5, 1, 2, 3],
+                [1, 3, 0, 2],
+                [2, 3, 5, 0],
+                [1, 6, 7, 5],
+            ),
+            dtype=np.float64,
+        )
+
+        data[1, :, :] = np.array(
+            (
+                [6, 5, 2, 7],
+                [8, 7, 6, 5],
+                [5, 2, 3, 6],
+                [0, 3, 4, 7],
+            ),
+            dtype=np.float64,
+        )
+
+        right = xr.Dataset(
+            {"im": (["band", "row", "col"], data)},
+            coords={"band": np.arange(data.shape[0]), "row": np.arange(data.shape[1]), "col": np.arange(data.shape[2])},
+        )
+
+        right.attrs = common.img_attrs
+
+        # Initialization of matching_cost plugin with wrong band
+        matching_cost_ = matching_cost.AbstractMatchingCost(
+            **{"matching_cost_method": "sad", "window_size": 3, "subpix": 1, "band": "b"}
+        )
+
+        # Compute the cost_volume
+        with pytest.raises(SystemExit):
+            _ = matching_cost_.compute_cost_volume(img_left=left, img_right=right, disp_min=-1, disp_max=1)
+
+        # Initialization of matching_cost plugin with no band
+        matching_cost_ = matching_cost.AbstractMatchingCost(
+            **{"matching_cost_method": "sad", "window_size": 3, "subpix": 1}
+        )
+
+        # Compute the cost_volume
+        with pytest.raises(SystemExit):
+            _ = matching_cost_.compute_cost_volume(img_left=left, img_right=right, disp_min=-1, disp_max=1)
+
 
 if __name__ == "__main__":
     common.setup_logging()
